Function bridge
fn bridge<impl AsRef<Path>: AsRef<std::path::Path>>(rust_source_file: impl AsRef<Path>) -> Build
This returns a cc::Build on which you should continue to set up any
additional source files or compiler flags, and lastly call its compile
method to execute the C++ build.